@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)            |
    |                          https://www.mrpt.org/                         |
    |                                                                        |
-   | Copyright (c) 2005-2021, Individual contributors, see AUTHORS file     |
+   | Copyright (c) 2005-2022, Individual contributors, see AUTHORS file     |
    | See: https://www.mrpt.org/Authors - All rights reserved.               |
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
@@ -37,6 +37,7 @@
 #include <mrpt/system/filesystem.h>
 
 #include <mutex>
+#include <optional>
 
 using namespace mrpt;
 using namespace mrpt::opengl;
@@ -131,7 +132,7 @@ struct RenderElements
 
 struct CAssimpModel::Impl
 {
-#if MRPT_HAS_OPENGL_GLUT && MRPT_HAS_ASSIMP
+#if (MRPT_HAS_OPENGL_GLUT || MRPT_HAS_EGL) && MRPT_HAS_ASSIMP
 	Impl() = default;
 	~Impl() = default;
 
@@ -148,7 +149,7 @@ struct CAssimpModel::Impl
 #endif
 };
 
-#if MRPT_HAS_OPENGL_GLUT && MRPT_HAS_ASSIMP
+#if (MRPT_HAS_OPENGL_GLUT || MRPT_HAS_EGL) && MRPT_HAS_ASSIMP
 
 // Just return the diffuse color:
 static mrpt::img::TColor apply_material(const aiMaterial* mtl);
@@ -200,7 +201,7 @@ void CAssimpModel::onUpdateBuffers_all()
 	auto& tris = CRenderizableShaderTriangles::m_triangles;
 	tris.clear();
 
-#if MRPT_HAS_OPENGL_GLUT && MRPT_HAS_ASSIMP
+#if (MRPT_HAS_OPENGL_GLUT || MRPT_HAS_EGL) && MRPT_HAS_ASSIMP
 	if (!m_assimp_scene->scene) return;	 // No scene
 
 	mrpt::opengl::internal::RenderElements re;
@@ -243,7 +244,7 @@ uint8_t CAssimpModel::serializeGetVersion() const { return 1; }
 void CAssimpModel::serializeTo(mrpt::serialization::CArchive& out) const
 {
 	writeToStreamRender(out);
-#if MRPT_HAS_OPENGL_GLUT && MRPT_HAS_ASSIMP
+#if (MRPT_HAS_OPENGL_GLUT || MRPT_HAS_EGL) && MRPT_HAS_ASSIMP
 	const bool empty = m_assimp_scene->scene != nullptr;
 	out << empty;
 	if (!empty)
@@ -286,7 +287,7 @@ void CAssimpModel::clear()
 {
 	CRenderizable::notifyChange();
 
-#if MRPT_HAS_OPENGL_GLUT && MRPT_HAS_ASSIMP
+#if (MRPT_HAS_OPENGL_GLUT || MRPT_HAS_EGL) && MRPT_HAS_ASSIMP
 	m_assimp_scene->importer.FreeScene();
 #endif
 	m_modelPath.clear();
@@ -296,7 +297,7 @@ void CAssimpModel::clear()
 
 void CAssimpModel::loadScene(const std::string& filepath, int flags)
 {
-#if MRPT_HAS_OPENGL_GLUT && MRPT_HAS_ASSIMP
+#if (MRPT_HAS_OPENGL_GLUT || MRPT_HAS_EGL) && MRPT_HAS_ASSIMP
 	clear();
 	CRenderizable::notifyChange();
 
@@ -361,7 +362,7 @@ bool CAssimpModel::traceRay(
 	return false;
 }
 
-#if MRPT_HAS_OPENGL_GLUT && MRPT_HAS_ASSIMP
+#if (MRPT_HAS_OPENGL_GLUT || MRPT_HAS_EGL) && MRPT_HAS_ASSIMP
 
 static void get_bounding_box_for_node(
 	const aiScene* scene, const aiNode* nd, aiVector3D* min, aiVector3D* max,
